==> tencent_calls_engine-1.5.3.tar.gz: README.md <==
# Tencent Cloud Engine for Video Calls

English | [简体中文](https://github.com/tencentyun/TUICallKit/blob/main/Flutter/README_zh-CN.md)

<img src="https://qcloudimg.tencent-cloud.cn/raw/ec034fc6e4cf42cae579d32f5ab434a1.png" align="left" width=120 height=120>TUICallKit is a UIKit about **audio&video calls** launched by Tencent Cloud. By integrating this component, you can write a few lines of code to use the video calling function, TUICallKit support offline calling and multiple  platforms such as Android, iOS, Web, Flutter(doing), etc.

<a href="https://apps.apple.com/cn/app/%E8%85%BE%E8%AE%AF%E4%BA%91%E8%A7%86%E7%AB%8B%E6%96%B9trtc/id1400663224"><img src="https://qcloudimg.tencent-cloud.cn/raw/afe9b8cc4c715346cf3d9feea8a65e33.svg" height=40></a> <a href="https://dldir1.qq.com/hudongzhibo/liteav/TRTCDemo.apk"><img src="https://qcloudimg.tencent-cloud.cn/raw/006d5ed3359640424955baa08dab7c7f.svg" height=40></a> <a href="https://web.sdk.qcloud.com/trtc/webrtc/demo/api-sample/login.html"><img src="https://qcloudimg.tencent-cloud.cn/raw/d326e70750f8bbad7245e229c5bd6d2b.svg" height=40></a>


**TUICallEngine is a video call API without UI. If the interaction of TUICallKit does not meet your needs, you can use this API to define your own UI.**

## Features

<p align="center">
  <img src="https://qcloudimg.tencent-cloud.cn/raw/7948ebb426462af84dbbfdd1f03e94c2.png"/>
</p>

- **Perfect UI interaction**: We provide TUICallKit, an open source component with UI, which can save your 90% of development time.and you can have a video calling app like WeChat or FaceTime in just 20 minutes.

- **Multi-platform interconnection**: We support various platforms such as Web, Android, iOS, WeChat applet, etc., as well as support cross-platform frameworks such as uni-app. You can use TUICallKit components from different platforms to support mutual calls and answers , hang up, etc. In the future, we also plan to support Flutter, MacOS, Windows and other devices.

- **Mobile terminal offline push**: We support offline wake-up on Android and iOS. When your app is offline, you can also receive call reminders in time. Currently, Google FCM, Apple, Xiaomi, Huawei, OPPO, VIVO, Meizu and other push services

- **Group (multi-person) calls**: We not only support 1-to-1 video calls, but also support multi-person video calls within a group, inviting group members to join in the middle, and support group members to actively join the call and more.

- **Multi-device login**: We also support the ability to log in to multiple devices on different platforms, your pad or mobile phone at the same time, for a larger screen and a more flexible experience.

- **More Features**: We also support multiple features such as custom ringtones, custom avatars, AI noise reduction, weak network optimization...



## Make a first call

Here is an example of integration with UI (ie TUICallKit),  which is also our recommended integration method. The key steps are as follows:

- **Step1**: Activate the [Tencent Cloud Audio and Video Call Service](https://console.cloud.tencent.com/vcube/project/manage), for developer integration, we also provide a free trial version, [More introduction](https://cloud.tencent.com/document/product/1640/81130).

- **Step2**: Access TUICallKit to your project, the detailed access process of each platform/framework: [Web](https://cloud.tencent.com/document/product/1640/81132), [ Android](https://cloud.tencent.com/document/product/647/78729), [iOS](https://cloud.tencent.com/document/product/647/78730).

- **Step3**: Make your first video call!


## Quick link

- If you encounter difficulties, you can refer to [FAQs](https://cloud.tencent.com/document/product/647/78767), here are the most frequently encountered problems of developers, covering various platforms, I hope you can Help you solve problems quickly.

- If you would like to see more official examples, you can refer to the example Demo of each platform: [Web](https://github.com/tencentyun/TUICallKit/tree/main/Web/), [Android](https://github.com/tencentyun/TUICallKit/tree/main/Android/), [iOS](https://github.com/tencentyun/TUICallKit/tree/main/iOS/).

- If you would like to see some of our latest product features, you can check the [Update Log](https://cloud.tencent.com/document/product/647/80931), here are the latest features of TUICallKit, as well as the historical version features iterate
- For complete API documentation, see [Audio Video Call SDK API Example](https://cloud.tencent.com/document/product/647/78748): including TUICallKit (with UIKit), TUICallEngine (without UIKit), and call events Callbacks, etc.
- If you want to learn more about the projects maintained by Tencent Cloud  Media Services Team, you can check our [Product Official Website](https://cloud.tencent.com/product/rtcube), [Github Organizations](https://github .com/LiteAVSDK) etc.



## Have any questions?
- Welcome to submit [**issue**](https://github.com/tencentyun/TUICallKit/issues),  
- Welcome to join our Telegram Group to communicate with our professional engineers! We are more than happy to hear from you，Click to join: https://t.me/+EPk6TMZEZMM5OGY1
Or scan the QR code 
<img src="https://qcloudimg.tencent-cloud.cn/raw/e5c765990e01621274517debf8b317ca.jpg"/>

==> tencent_calls_engine-2.0.1.tar.gz: README.md <==
# Tencent Cloud Engine for Video Calls

English | [简体中文](https://github.com/tencentyun/TUICallKit/blob/main/Flutter/README_zh-CN.md)

<img src="https://qcloudimg.tencent-cloud.cn/raw/ec034fc6e4cf42cae579d32f5ab434a1.png" align="left" width=120 height=120>TUICallKit is a UIKit about **audio&video calls** launched by Tencent Cloud. By integrating this component, you can write a few lines of code to use the video calling function, TUICallKit support offline calling and multiple  platforms such as Android, iOS, Web, Flutter(doing), etc.

<a href="https://apps.apple.com/cn/app/%E8%85%BE%E8%AE%AF%E4%BA%91%E8%A7%86%E7%AB%8B%E6%96%B9trtc/id1400663224"><img src="https://qcloudimg.tencent-cloud.cn/raw/afe9b8cc4c715346cf3d9feea8a65e33.svg" height=40></a> <a href="https://dldir1.qq.com/hudongzhibo/liteav/TRTCDemo.apk"><img src="https://qcloudimg.tencent-cloud.cn/raw/006d5ed3359640424955baa08dab7c7f.svg" height=40></a> <a href="https://web.sdk.qcloud.com/trtc/webrtc/demo/api-sample/login.html"><img src="https://qcloudimg.tencent-cloud.cn/raw/d326e70750f8bbad7245e229c5bd6d2b.svg" height=40></a>


**TUICallEngine is a video call API without UI. If the interaction of TUICallKit does not meet your needs, you can use this API to define your own UI.**

## Features

<p align="center">
  <img src="https://qcloudimg.tencent-cloud.cn/raw/7948ebb426462af84dbbfdd1f03e94c2.png"/>
</p>

- **Perfect UI interaction**: We provide TUICallKit, an open source component with UI, which can save your 90% of development time.and you can have a video calling app like WeChat or FaceTime in just 20 minutes.

- **Multi-platform interconnection**: We support various platforms such as Web, Android, iOS, WeChat applet, etc., as well as support cross-platform frameworks such as uni-app. You can use TUICallKit components from different platforms to support mutual calls and answers , hang up, etc. In the future, we also plan to support Flutter, MacOS, Windows and other devices.

- **Mobile terminal offline push**: We support offline wake-up on Android and iOS. When your app is offline, you can also receive call reminders in time. Currently, Google FCM, Apple, Xiaomi, Huawei, OPPO, VIVO, Meizu and other push services

- **Group (multi-person) calls**: We not only support 1-to-1 video calls, but also support multi-person video calls within a group, inviting group members to join in the middle, and support group members to actively join the call and more.

- **Multi-device login**: We also support the ability to log in to multiple devices on different platforms, your pad or mobile phone at the same time, for a larger screen and a more flexible experience.

- **More Features**: We also support multiple features such as custom ringtones, custom avatars, AI noise reduction, weak network optimization...



## Make a first call

Here is an example of integration with UI (ie TUICallKit),  which is also our recommended integration method. The key steps are as follows:

- **Step1**: Activate the [Tencent Cloud Audio and Video Call Service](https://console.cloud.tencent.com/vcube/project/manage), for developer integration, we also provide a free trial version, [More introduction](https://cloud.tencent.com/document/product/1640/81130).

- **Step2**: Access TUICallKit to your project, the detailed access process of each platform/framework: [Web](https://cloud.tencent.com/document/product/1640/81132), [ Android](https://cloud.tencent.com/document/product/647/78729), [iOS](https://cloud.tencent.com/document/product/647/78730).

- **Step3**: Make your first video call!


## Quick link

- If you encounter difficulties, you can refer to [FAQs](https://cloud.tencent.com/document/product/647/78767), here are the most frequently encountered problems of developers, covering various platforms, I hope you can Help you solve problems quickly.

- If you would like to see more official examples, you can refer to the example Demo of each platform: [Web](https://github.com/tencentyun/TUICallKit/tree/main/Web/), [Android](https://github.com/tencentyun/TUICallKit/tree/main/Android/), [iOS](https://github.com/tencentyun/TUICallKit/tree/main/iOS/).

- If you would like to see some of our latest product features, you can check the [Update Log](https://cloud.tencent.com/document/product/647/80931), here are the latest features of TUICallKit, as well as the historical version features iterate
- For complete API documentation, see [Audio Video Call SDK API Example](https://cloud.tencent.com/document/product/647/78748): including TUICallKit (with UIKit), TUICallEngine (without UIKit), and call events Callbacks, etc.
- If you want to learn more about the projects maintained by Tencent Cloud  Media Services Team, you can check our [Product Official Website](https://trtc.tencentcloud.com/), [Github Organizations](https://github .com/LiteAVSDK) etc.



## Have any questions?
- Welcome to submit [**issue**](https://github.com/tencentyun/TUICallKit/issues),  
- Welcome to join our Telegram Group to communicate with our professional engineers! We are more than happy to hear from you，Click to join: https://t.me/+EPk6TMZEZMM5OGY1
Or scan the QR code 
<img src="https://qcloudimg.tencent-cloud.cn/raw/e5c765990e01621274517debf8b317ca.jpg"/>
